from blueness.argparse.generic import main

from abadpour import NAME, VERSION, DESCRIPTION, ICON
from abadpour.build import build
from abadpour.logger import logger

main(
    ICON=ICON,
    NAME=NAME,
    DESCRIPTION=DESCRIPTION,
    VERSION=VERSION,
    main_filename=__file__,
    tasks={
        "build": lambda _: build(),
    },
    logger=logger,
)



NAME = "abadpour"

ICON = "📜"

DESCRIPTION = f"{ICON} Arash Abadpour's CV."

VERSION = "6.103.1"

ALIAS = NAME

MARQUEE = (
    "https://github.com/kamangir/assets/blob/main/abadpour/2020-11-21.jpg?raw=true"
)



from blueness import module
from blue_options.help.functions import help_main

from abadpour import NAME
from abadpour.help.functions import help_functions

NAME = module.name(__file__, NAME)


help_main(NAME, help_functions)
